@@ -54,11 +54,10 @@ static void quit(GtkWidget *widget _U_, gpointer data, guint action _U_) {
   struct session_t *session = (struct session_t *) data;
   
   settings_history_write(session); /* write history */
+  settings_callerid_write(session); /* write callerid history */
   
   gtk_handle_hang_up_button(NULL, data); /* simulate hang_up_button */
 
-  session_set_state(session, STATE_SERVICE);
-
   /* some (GUI) de-initialization, not directly session related */
   llcheck_bar_deinit(session->llcheck_in);
   llcheck_bar_deinit(session->llcheck_out);
@@ -187,7 +186,8 @@ void show_audio_error_dialog() {
   dialog = ok_dialog_get("ANT Note",
 			 "Can't open audio device.\n"
 			 "Please stop other applications using\n"
-			 "the audio device(s) and try again.",
+			 "the audio device(s) or check your\n"
+			 "device settings and try again.",
 			 GTK_JUSTIFY_CENTER);
   gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
   gtk_widget_show(dialog);
@@ -207,23 +207,30 @@ struct info_row_t {
 };
 
 /* Info window */
-static void cb_info_window(GtkWidget *widget _U_, gpointer data, guint action _U_) {
+static void cb_info_window(GtkWidget *widget _U_, gpointer data,
+			   guint action _U_) {
   struct session_t *session = (struct session_t *) data;
+  int inactive = session->option_release_devices &&
+    (session->state == STATE_READY || session->state == STATE_RINGING_QUIET);
   struct info_row_t rows[] = {
     { "Sound input device:", strdup(session->audio_device_name_in)},
-    { "Input speed:", ltostr(session->audio_speed_in) },
-    { "Input sample size (bits):", ltostr(session->audio_sample_size_in * 8)},
-    { "Input fragment size (samples):",
+    { "Input speed:", inactive ? strdup("[inactive]") :
+      ltostr(session->audio_speed_in) },
+    { "Input sample size (bits):", inactive ?
+       strdup("[inactive]") : ltostr(session->audio_sample_size_in * 8)},
+    { "Input fragment size (samples):", inactive ? strdup("[inactive]") :
       ltostr(session->fragment_size_in / session->audio_sample_size_in)},
-    { "Input channels:", ltostr(1) },
+    { "Input channels:", inactive ? strdup("[inactive]") : ltostr(1) },
     { "", strdup("") },
 
     { "Sound output device:", strdup(session->audio_device_name_out)},
-    { "Output speed:", ltostr(session->audio_speed_out) },
-    { "Output sample size (bits):", ltostr(session->audio_sample_size_out*8)},
-    { "Input fragment size (samples):",
+    { "Output speed:", inactive ? strdup("[inactive]") :
+      ltostr(session->audio_speed_out) },
+    { "Output sample size (bits):", inactive ?
+      strdup("[inactive]") : ltostr(session->audio_sample_size_out*8)},
+    { "Input fragment size (samples):", inactive ? strdup("[inactive]") :
       ltostr(session->fragment_size_out / session->audio_sample_size_out)},
-    { "Output channels:", ltostr(1) },
+    { "Output channels:", inactive ? strdup("[inactive]") : ltostr(1) },
     { "", strdup("") },
 
     { "ISDN device:", strdup(session->isdn_device_name) },
@@ -302,7 +309,7 @@ static void cb_about(GtkWidget *widget _U_, gpointer data _U_, guint action _U_)
   GtkWidget *window = ok_dialog_get("About ANT",
 			"ANT (ANT is Not a Telephone) Version " VERSION "\n"
 			"Copyright 2002 Roland Stigge\n\n"
-			"This is a small ISDN telephone application\n"
+			"This is an ISDN telephone application\n"
 			"written for GNU/Linux and ISDN4Linux for\n"
 			"communicating via a full duplex soundcard (or\n"
 			"multiple sound devices if you like) and an\n"
@@ -665,6 +672,7 @@ int main_gtk(struct session_t *session) {
   gtk_widget_show(main_window);
 
   settings_history_read(session); /* get history from home dir dotfile */
+  settings_callerid_read(session); /* get callerid history */
 
   /* connect isdn and sound input handlers to gdk pseudo select */
   session_io_handlers_start(session);
