@@ -10,4 +10,7 @@
 /* own header files */
 #include "session.h"
 
+GtkWidget *ok_dialog_get(char *title, char *contents,
+			 GtkJustification justification);
+void show_audio_error_dialog();
 int main_gtk(struct session_t *session);
