@@ -32,6 +32,7 @@
 #include "util.h"
 #include "mediation.h"
 #include "llcheck.h"
+#include "fxgenerator.h"
 
 /*
  * allocate memory and build look-up-tables for audio <-> isdn conversion
@@ -232,7 +233,22 @@ void process_isdn_source(struct session_t *session) {
       inbyte = session->isdn_inbuf[i];
       if (!session->escape == (inbyte != DLE)) {
 	/* normal mode or last byte was an escape in DLE mode */
-	  
+	
+	/* input line level check */
+	sample = session->audio_LUT_analyze[inbyte];
+	if (abs((int)sample - 128) > max)
+	  max = abs((int)sample - 128);
+
+	/* touchtone to audio: after llcheck to monitor other end */
+	if (session->touchtone_countdown_audio > 0) {
+	  inbyte = fxgenerate(session, EFFECT_TOUCHTONE,
+			      session->touchtone_index,
+			      (double)session->touchtone_countdown_audio /
+			      ISDN_SPEED); /* playing reverse is ok */
+	  session->touchtone_countdown_audio--;
+	}
+
+	/* mediation */
 	to_process = (int)floor((double)(session->samples_in + 1) *
 				session->ratio_in) -
 	             (int)floor((double)session->samples_in *
@@ -256,11 +272,6 @@ void process_isdn_source(struct session_t *session) {
 	  }
 	}
 
-	/* input line level check */
-	sample = session->audio_LUT_analyze[inbyte];
-	if (abs((int)sample - 128) > max)
-	  max = abs((int)sample - 128);
-
 	session->samples_in++;
 
 	if (session->escape) {
@@ -305,6 +316,8 @@ void process_isdn_source(struct session_t *session) {
 void process_audio_source(struct session_t *session) {
   int i, j, got, n;
   unsigned char sample; /* the ulaw sample */
+  /* the ulaw sample when muted */
+  unsigned char zero = session->audio_LUT_generate[128];
   int to_process; /* number of samples to process
                      (according to ratio / ratio_support_count) */
   unsigned char sampleu8; /* 8 bit unsigned sample */
@@ -336,10 +349,22 @@ void process_audio_source(struct session_t *session) {
 					  << 8];
 	}
 	
+	/* touchtone to isdn: before llcheck to monitor it */
+	if (session->touchtone_countdown_isdn > 0) {
+	  sample = fxgenerate(session, EFFECT_TOUCHTONE,
+			      session->touchtone_index,
+			      (double)session->touchtone_countdown_isdn /
+			      ISDN_SPEED /* playing reverse is ok */ );
+	  session->touchtone_countdown_isdn--;
+	}
+
 	/* input line level check */
 	sampleu8 = session->audio_LUT_analyze[sample];
 	if (abs((int)sampleu8 - 128) > max)
 	  max = abs((int)sampleu8 - 128);
+	
+	if (session->option_muted) /* zero if muted */
+	  sample = zero;
 
 	n = (sample == DLE) ? 2 : 1; /* again if DLE escape */
 	while (n > 0) {
