@@ -1,14 +1,14 @@
-/* A Bison parser, made from optionsparser.y
+/* A Bison parser, made from /home/ernie/code/ant/optionsparser.y
    by GNU bison 1.35.  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
 #define YYLSP_NEEDED 1
 
-# define	TOKEN_WORD	257
-# define	TOKEN_NUMBER	258
-# define	TOKEN_STRING	259
-# define	TOKEN_EQUALS	260
+# define	OPT_TOKEN_WORD	257
+# define	OPT_TOKEN_NUMBER	258
+# define	OPT_TOKEN_STRING	259
+# define	OPT_TOKEN_EQUALS	260
 
 #line 1 "optionsparser.y"
 
@@ -21,6 +21,9 @@
  *
  */
 
+/* redefine symbols to allow multiple parsers in same executable */
+#include "optionsredefines.h"
+
 /* type for semantic values of symbols: malloc'ed strings */
 #define YYSTYPE char *
 
@@ -129,8 +132,8 @@ static const short yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined. */
 static const short yyrline[] =
 {
-       0,    45,    46,    49,    50,    54,    59,    68,    69,    82,
-      83,    84
+       0,    48,    49,    52,    53,    57,    62,    71,    72,    85,
+      86,    87
 };
 #endif
 
@@ -140,8 +143,9 @@ static const short yyrline[] =
 /* YYTNAME[TOKEN_NUM] -- String name of the token TOKEN_NUM. */
 static const char *const yytname[] =
 {
-  "$", "error", "$undefined.", "TOKEN_WORD", "TOKEN_NUMBER", "TOKEN_STRING", 
-  "TOKEN_EQUALS", "'\\n'", "settings", "line", "values", "value", 0
+  "$", "error", "$undefined.", "OPT_TOKEN_WORD", "OPT_TOKEN_NUMBER", 
+  "OPT_TOKEN_STRING", "OPT_TOKEN_EQUALS", "'\\n'", "settings", "line", 
+  "values", "value", 0
 };
 #endif
 
@@ -907,20 +911,20 @@ yyreduce:
   switch (yyn) {
 
 case 4:
-#line 51 "optionsparser.y"
+#line 54 "optionsparser.y"
 { settings_option_set(session, yyvsp[-1], "1");
 	         free(yyvsp[-1]);
 	       }
     break;
 case 5:
-#line 55 "optionsparser.y"
+#line 58 "optionsparser.y"
 { settings_option_set(session, yyvsp[-3], yyvsp[-1]);
 		 free(yyvsp[-3]);
 		 free(yyvsp[-1]);
 	       }
     break;
 case 6:
-#line 60 "optionsparser.y"
+#line 63 "optionsparser.y"
 { if (debug)
 	         fprintf(stderr,
 		         "Warning: "
@@ -929,7 +933,7 @@ case 6:
 	     }
     break;
 case 8:
-#line 70 "optionsparser.y"
+#line 73 "optionsparser.y"
 { if (asprintf(&yyval, "%s %s", yyvsp[-1], yyvsp[0]) < 0) { /* allocated? */
 		   fprintf(stderr, "Warning: "
 			   "Couldn't allocate memory for compound value.\n");
@@ -1174,7 +1178,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 87 "optionsparser.y"
+#line 90 "optionsparser.y"
 
 
 /*
