@@ -20,10 +20,10 @@ typedef struct yyltype
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
-# define	TOKEN_WORD	257
-# define	TOKEN_NUMBER	258
-# define	TOKEN_STRING	259
-# define	TOKEN_EQUALS	260
+# define	OPT_TOKEN_WORD	257
+# define	OPT_TOKEN_NUMBER	258
+# define	OPT_TOKEN_STRING	259
+# define	OPT_TOKEN_EQUALS	260
 
 
 extern YYSTYPE yylval;
