@@ -32,6 +32,7 @@
 #include "llcheck.h"
 #include "settings.h"
 #include "fxgenerator.h"
+#include "server.h"
 
 /*
  * This is our session. Currently just one globally.
@@ -277,6 +278,7 @@ int session_init(struct session_t *session,
   session->dial_number_history = g_list_append(session->dial_number_history,
   					       strdup(""));
   session->dial_number_history_maxlen = 10; /* config overrides this */
+  session->cid_num_max = 0; /* 0 means no limit */
 
   /* defaults */
   session->option_save_options = 1; /* save options automatically (on exit) */
@@ -286,6 +288,8 @@ int session_init(struct session_t *session,
   session->option_show_controlpad = 1;
   session->option_muted = 0;
 
+  session->exec_on_incoming = strdup("");
+
   session->audio_device_name_in = strdup(audio_device_name_in);
   session->audio_device_name_out = strdup(audio_device_name_out);
   session->msn = strdup(msn);
@@ -319,12 +323,16 @@ int session_init(struct session_t *session,
   session->touchtone_index = 0;
 
   /* setup audio and isdn */
-  if (session_audio_init(session) < 0) return -1;
+  if (!session->option_release_devices)
+    if (session_audio_init(session) < 0) return -1;
   if (session_isdn_init(session) < 0) return -1;
 
-  session->state = STATE_SERVICE; /* initial state */
+  session->state = STATE_READY; /* initial state */
 
   session->effect = EFFECT_NONE;
+
+  /* init server functionality */
+  if (server_init(session) < 0) return -1;
   
   return 0;
 }
@@ -342,9 +350,12 @@ void free_g_list_element(gpointer data, gpointer user_data _U_) {
  *
  * input: session: session to de-initialize
  *
- * returns 0 un success, -1 otherwise
+ * returns 0 on success, -1 otherwise
  */
 int session_deinit(struct session_t *session) {
+
+  /* deinit server functionality */
+  if (server_deinit(session) < 0) return -1;
   
   if (session->option_save_options) settings_options_write(session);
 
@@ -354,7 +365,10 @@ int session_deinit(struct session_t *session) {
 
   /* close devices and clean up (buffers) */
   if (session_isdn_deinit(session) < 0) return -1;
-  if (session_audio_deinit(session) < 0) return -1;
+  if (!session->option_release_devices)
+    if (session_audio_deinit(session) < 0) return -1;
+
+  free(session->exec_on_incoming);
 
   /* clean up pre-set options */
   free(session->audio_device_name_in);
@@ -381,6 +395,12 @@ void session_io_handlers_start(struct session_t *session) {
 					      GDK_INPUT_READ,
 					      gdk_handle_isdn_input,
 					      (gpointer) session);
+
+  /* server functionality */
+  session->gdk_local_input_tag = gdk_input_add(session->local_sock,
+					       GDK_INPUT_READ,
+					       server_handle_local_input,
+					       (gpointer) session);
 }
 
 /*
@@ -393,6 +413,7 @@ void session_io_handlers_stop(struct session_t *session) {
     gdk_input_remove(session->gdk_audio_input_tag);
   }
   gdk_input_remove(session->gdk_isdn_input_tag);
+  gdk_input_remove(session->gdk_local_input_tag);
 }
 
 /*
@@ -455,7 +476,7 @@ void session_new_modem_string_callback(struct session_t *session) {
  *         non-compleded lines are 1-terminated there
  *       * completed lines are actually terminated by "\r\n\0"
  */
-int isdn_try_read_line(struct session_t *session) {
+static int isdn_try_read_line(struct session_t *session) {
   int total = 0; /* number of bytes read in this call */
   struct timeval tv;
   fd_set fds;
@@ -653,12 +674,12 @@ int session_set_state(struct session_t *session, enum state_t state) {
   if (session->option_release_devices && state != session->state) {
     if (state == STATE_READY && session->state != STATE_RINGING_QUIET) {
       /* release */
-      session_audio_close(session);
+      session_audio_deinit(session);
     } else if ((session->state == STATE_READY ||
 		session->state == STATE_RINGING_QUIET) &&
 	       state != STATE_READY && state != STATE_RINGING_QUIET) {
       /* (try to) resume */
-      if (session_audio_open(session)) {
+      if (session_audio_init(session)) {
 	state = session->state;
 	result = -1;
       }
@@ -676,26 +697,32 @@ int session_set_state(struct session_t *session, enum state_t state) {
   case STATE_DIALING:
     if (session->effect == EFFECT_NONE)
       session_effect_start(session, EFFECT_RINGING);
+    if (debug) fprintf(stderr, "New state: STATE_DIALING\n");
     break;
   case STATE_RINGING:
     if (session->effect == EFFECT_NONE)
       session_effect_start(session, EFFECT_RING);
+    if (debug) fprintf(stderr, "New state: STATE_RINGING\n");
     break;
   case STATE_RINGING_QUIET:
+    if (debug) fprintf(stderr, "New state: STATE_RINGING_QUIET\n");
     break;
   case STATE_READY:
     gtk_widget_grab_focus(GTK_WIDGET(GTK_COMBO(session->dial_number_box)
 				     ->entry));
     if (session->effect != EFFECT_NONE)
       session_effect_stop(session);
+    if (debug) fprintf(stderr, "New state: STATE_READY\n");
     break;
   case STATE_CONVERSATION:
     if (session->effect != EFFECT_NONE)
       session_effect_stop(session);
     session->touchtone_countdown_isdn = 0;
     session->touchtone_countdown_audio = 0;
+    if (debug) fprintf(stderr, "New state: STATE_CONVERSATION\n");
     break;
   case STATE_SERVICE:
+    if (debug) fprintf(stderr, "New state: STATE_SERVICE\n");
     break;
   default:
     fprintf(stderr, "Warning: session_set_state: Unhandled state.\n");
@@ -744,18 +771,27 @@ int session_set_state(struct session_t *session, enum state_t state) {
 void gdk_handle_isdn_input(gpointer data, gint fd _U_,
 			   GdkInputCondition condition _U_) {
   struct session_t *session = (struct session_t *) data;
+  char *temp;
 
   switch (session->state) {
   case STATE_READY: /* we are in command mode */
     if (isdn_try_read_line(session)){ /* got new line: something happened */
       if (!strncmp(session->isdn_inbuf, "RING/", 5)) { /* -> RINGING state */
-	if (session_set_state(session, STATE_RINGING))
-	  session_set_state(session, STATE_RINGING_QUIET);
-
 	session->isdn_inbuf[session->isdn_inbuf_len - 2] = 0;
 	/* caller id update */
 	cid_add_line(session, CALL_IN, NULL, &session->isdn_inbuf[5]);
 
+	/* execute command if given */
+	if (session->exec_on_incoming) {
+	  temp = strdup(session->exec_on_incoming);
+	  substitute(&temp, "%n", &session->isdn_inbuf[5]);
+	  execute(temp);
+	  free(temp);
+	}
+
+	if (session_set_state(session, STATE_RINGING))
+	  session_set_state(session, STATE_RINGING_QUIET);
+
       } else { /* something else */
       }
     }
@@ -900,6 +936,16 @@ void gdk_handle_audio_input(gpointer data, gint fd _U_,
   }
 }
 
+/*
+ * initiates dialing to specified number
+ * -> changes contents of dial entry and simulates pick up button
+ */
+void session_make_call(struct session_t *session, char *number) {
+  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(session->dial_number_box)->entry),
+		     number);
+  gtk_button_clicked(GTK_BUTTON(session->pick_up_button));
+}
+
 /*
  * callback for GTK on pick up button clicked
  *
@@ -1021,7 +1067,7 @@ void gtk_handle_hang_up_button(GtkWidget *widget _U_, gpointer data) {
 static void session_history_normalize(struct session_t *session) {
   /* cut size if needed */
   while (g_list_length(session->dial_number_history) >
-	 session->dial_number_history_maxlen) {
+	 session->dial_number_history_maxlen + 1) {
     free(g_list_nth_data(session->dial_number_history,
 			 g_list_length(session->dial_number_history) - 1));
     session->dial_number_history = g_list_remove_link(
