@@ -12,9 +12,15 @@
 
 #define SETTINGS_OPTIONS_FILENAME "options"
 #define SETTINGS_HISTORY_FILENAME "history"
+#define SETTINGS_CALLERID_HISTORY_FILENAME "callerid"
+
 
 void settings_option_set(struct session_t *session, char *option, char *value);
 void settings_options_read(struct session_t *session);
 void settings_options_write(struct session_t *session);
+
 void settings_history_read(struct session_t *session);
 void settings_history_write(struct session_t *session);
+
+void settings_callerid_read(struct session_t *session);
+void settings_callerid_write(struct session_t *session);
