@@ -7,14 +7,24 @@
  *
  */
 
+#include "config.h"
+
 #include <stdio.h>
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
-#include <unistd.h>
-#include <fcntl.h>
+#endif
+#ifdef HAVE_UNISTD_H
+  #include <unistd.h>
+#endif
+#ifdef HAVE_FCNTL_H
+  #include <fcntl.h>
+#endif
 #include <math.h>
 #include <errno.h>
 #include <sys/soundcard.h>
-#include <stdlib.h>
+#ifdef HAVE_STDLIB_H
+  #include <stdlib.h>
+#endif
 #include <string.h>
 
 #include "sound.h"
@@ -255,7 +265,7 @@ int audio_stop(int audio_fd_in, int audio_fd_out) {
   /* flush input buffer */
   if (ioctl(audio_fd_in, SNDCTL_DSP_GETBLKSIZE, &frag_size))
     fprintf(stderr, "Error obtaining audio input fragment size "
-	    "with SNDCTL_DSP_GETBLKSIZE.\n");
+	    "with SNDCTL_DSP_GETBLKSIZE in audio_stop().\n");
   else {
     buf = (char *) malloc(frag_size);
     
@@ -292,12 +302,12 @@ int audio_stop(int audio_fd_in, int audio_fd_out) {
 int close_audio_devices(int audio_fd_in, int audio_fd_out) {
   audio_stop(audio_fd_in, audio_fd_out);
 
-  if (close(audio_fd_in)) {
+  if (close(audio_fd_in) == -1) {
     perror("close audio device");
     return -1;
   }
   if (audio_fd_in != audio_fd_out)
-    if (close(audio_fd_out)) {
+    if (close(audio_fd_out) == -1) {
       perror("close audio device");
       return -1;
     }
