@@ -30,5 +30,9 @@ void ant_sleep(int usecs);
 char *un_vanity(char *s);
 char *timediff_str(time_t time1, time_t time0);
 char *ltostr(long int i);
+void execute(char *command);
+char *get_homedir();
+int touch_dotdir();
+int substitute(char **s, char *x, char *y);
 
 #endif /* util.h */
